@@ -5,7 +5,7 @@ Plugin.create :home_timeline do
     refresh_tab
   end
 
-  on_world_create do |world|
+  on_world_after_created do |world|
     refresh_tab
   end
 
