@@ -8,7 +8,7 @@ Plugin.create :mentions do
     refresh_tab
   end
 
-  on_world_create do |world|
+  on_world_after_created do |world|
     refresh_tab
   end
 
