@@ -1,3 +1,4 @@
+
 # coding: utf-8
 require 'nokogiri'
 require 'httpclient'
@@ -292,4 +293,10 @@ Plugin.create :photo_support do
     img = Plugin::PhotoSupport.インスタ映え(display_url)
     open(img) if img
   end
+
+  # pixiv
+  defimageopener('pixiv', %r<https?://(?:www\.)?pixiv\.net/member_illust\.php\?(?:.*)&?illust_id=\d+(?:&.*)?$>) do |display_url|
+    img = Plugin::PhotoSupport.インスタ映え(display_url)
+    open(img) if img
+  end
 end
