@@ -41,8 +41,6 @@ Plugin::create(:basic_settings) do
     end
 
     settings _('リアルタイム更新') do
-      boolean(_('ホームタイムライン(UserStream)'), :realtime_rewind).
-        tooltip _('Twitter の UserStream APIを用いて、リアルタイムにツイートやフォローなどのイベントを受け取ります')
       boolean(_('リスト(Streaming API)'), :filter_realtime_rewind).
         tooltip _('Twitter の Streaming APIを用いて、リアルタイムにリストの更新等を受け取ります')
     end
@@ -54,10 +52,10 @@ Plugin::create(:basic_settings) do
     about (_("%s について") % Environment::NAME), {
       :name => Environment::NAME,
       :version => Environment::VERSION.to_s,
-      :copyright => _('2009-%s Toshiaki Asai') % '2018',
+      :copyright => _('2009-%s Toshiaki Asai') % '2019',
       :comments => _("全てのミク廃、そしてTwitter中毒者へ贈る、至高のTwitter Clientを目指すTwitter Client。\n略して至高のTwitter Client。\n圧倒的なかわいさではないか我がミクは\n\nこのソフトウェアは %{license} によって浄化されています。") % {license: 'MIT License'},
       :license => (file_get_contents('../LICENSE') rescue nil),
-      :website => _('http://mikutter.hachune.net/'),
+      :website => _('https://mikutter.hachune.net/'),
       :logo => Skin.photo('icon.png'),
       :authors => ['toshi_a', 'Phenomer', 'osa_k', 'katsyoshi', 'ahiru', 'cobodo'],
       :artists => ['toshi_a', 'soramame_bscl', 'seibe2'],
