@@ -239,16 +239,9 @@ Plugin.create(:twitter) do
     }
   end
 
-  defspell(:remain_charcount, :twitter) do |twitter, body:|
-    body = trim_hidden_regions(body)
-    Twitter::TwitterText::Extractor.extract_urls(body).map{|url|
-      posted_url_length = Plugin.filtering(:tco_url_length, url, 0).last
-      if url.length < posted_url_length
-        -(posted_url_length - url.length)
-      else
-        url.length - posted_url_length
-      end
-    }.inject(140 - body.size, &:+)
+  defspell(:remain_charcount, :twitter) do |_twitter, body:|
+    tweet = Twitter::TwitterText::Validation.parse_tweet(trim_hidden_regions(body))
+    280 - tweet[:weighted_length]
   end
 
   def trim_hidden_regions(text)
@@ -412,11 +405,18 @@ Plugin.create(:twitter) do
       result = extended_entities.map{ |media|
         case media[:type]
         when 'photo'
-          photo = Diva::Model(:photo).generate(photo_variant_seeds(media), perma_link: media[:media_url_https])
-          Diva::Model(:score_hyperlink).new(
-            description: photo.uri,
-            uri: photo.uri,
-            reference: photo)
+          photo = Diva::Model(:photo)&.generate(photo_variant_seeds(media), perma_link: media[:media_url_https])
+          photo ||= Enumerator.new{|y| Plugin.filtering(:photo_filter, media[:media_url_https], y) }.first
+          if photo
+            Diva::Model(:score_hyperlink).new(
+              description: photo.uri,
+              uri: photo.uri,
+              reference: photo)
+          else
+            Diva::Model(:score_hyperlink).new(
+              description: media[:media_url_https],
+              uri: media[:media_url_https])
+          end
         when 'video'
           variant = Array(media[:video_info][:variants])
                       .select{|v|v[:content_type] == "video/mp4"}
@@ -527,7 +527,6 @@ Plugin.create(:twitter) do
     score << text_note(description: lead)
     if !(target.empty? || trail.empty?)
       trim = target[1, target.size]
-      puts({trim: trim, target: target})
       score << Diva::Model(:score_hyperlink).new(
         description: target,
         uri: uri_generator.(trim),
