@@ -73,7 +73,11 @@ Plugin.create :user_detail_view do
       order do |message|
         retweet = message.retweeted_statuses.find{ |r| user_id == r.user.id }
         (retweet || message)[:created].to_i end end
-    Service.primary.user_timeline(user_id: user_id, include_rts: 1, count: [UserConfig[:profile_show_tweet_once], 200].min).next{ |tl|
+    Enumerator.new{|y|
+      Plugin.filtering(:worlds, y)
+    }.select{|world|
+      world.class.slug == :twitter
+    }.first.user_timeline(user_id: user_id, include_rts: 1, count: [UserConfig[:profile_show_tweet_once], 200].min).next{ |tl|
       i_timeline << tl
     }.terminate(_("@%{user} の最近のつぶやきが取得できませんでした。見るなってことですかね") % {user: model[:idname]})
     timeline_storage[i_timeline.slug] = model end
@@ -248,10 +252,11 @@ Plugin.create :user_detail_view do
               detach(:followings_created, handler_followings_created)
               detach(:followings_destroy, handler_followings_destroy)
               false }
-            followbutton.sensitive = true end
+            followbutton.sensitive = true
+            relation_container.closeup(followbutton) end
         }.terminate.trap{
           w_following_label.text = _("取得できませんでした") } end
-      container.closeup(relation_container.closeup(followbutton)) }
+      container.closeup(relation_container) }
     container end
 
   # ユーザのプロフィールのヘッダ部を返す
