@@ -33,7 +33,16 @@ module Plugin::World
         @@service_lock.synchronize do
           @account_data ||= if FileTest.exist? ACCOUNT_FILE
             File.open(ACCOUNT_FILE, 'rb'.freeze) do |file|
-              YAML.load(decrypt(file.read))
+              decrypted_string = decrypt(file.read)
+              begin
+                JSON.parse(decrypted_string, symbolize_names: true)
+              rescue JSON::ParserError
+                # 3.6.4以前はYAMLになっている。
+                # 構造自体には互換性があるため単純にJSONにコンバートする
+                d = account_write(YAML.load(decrypted_string))
+                notice 'Older account data was detected. It was converted newer format.'
+                d
+              end
             end
           else
             migrate_older_account_data
@@ -108,7 +117,7 @@ module Plugin::World
     def account_write(account_data = @account_data)
       FileUtils.mkdir_p File.dirname(ACCOUNT_FILE)
       File.open(ACCOUNT_TMP, 'wb'.freeze) do |file|
-        file << encrypt(YAML.dump(account_data)) end
+        file << encrypt(JSON.dump(account_data)) end
       FileUtils.mv(ACCOUNT_TMP, ACCOUNT_FILE)
       account_data end
 
